/**
 * Copyright (c) 2017-2023 Governikus GmbH & Co. KG, Germany
 */

#include "IfdServer.h"

using namespace governikus;


IfdServer::~IfdServer() = default;
